@@ -30,7 +30,6 @@ from tgtlg .helper_funcs.extract_link_from_message import extract_link
 from tgtlg .helper_funcs.upload_to_tg import upload_to_gdrive, upload_to_tg
 from tgtlg .helper_funcs.direct_link_generator import direct_link_generator
 from tgtlg .helper_funcs.exceptions import DirectDownloadLinkException
-
 sys.setrecursionlimit(10 ** 4)
 
 def KopyasizListe(string):
@@ -279,7 +278,7 @@ async def call_apropriate_function(
                     message_to_send += "\n"
                 if message_to_send != "":
                     mention_req_user = (
-                        f"<a href='tg://user?id={update.from_user.id}'>{update.from_user.first_name}</a>'>Your requested files</a>\n\n"
+                        f"<a href='tg://user?id={message.from_user.id}'>{message.from_user.first_name}</a>'>Your requested files</a>\n\n"
                     )
                     message_to_send = mention_req_user + message_to_send
                     message_to_send = message_to_send + "\n\n" + "#uploads"
