@@ -20,7 +20,8 @@ from hurry.filesize import size
 from PIL import Image
 from pyrogram.errors import FloodWait, MessageNotModified
 from pyrogram.types import InlineKeyboardButton, InlineKeyboardMarkup, Message
-from pyrogram.types import InputMediaAudio, InputMediaDocument, InputMediaVideo
+from pyrogram.types import InputMediaAudio, InputMediaDocument, 
+from pyrogram.types import CallbackQuery
 from requests.utils import requote_uri
 from tgtlg import (
     DESTINATION_FOLDER,
@@ -73,7 +74,7 @@ async def upload_to_tg(
         new_m_esg = message
         if not message.photo:
             new_m_esg = await message.reply_text(
-                f"Found {len(directory_contents)} files <a href='tg://user?id={message.from_user.id}'>{message.from_user.first_name}</a>",
+                f"Found {len(directory_contents)} files <a href='tg://user?id={update.message.from_user.id}'>{update.message.from_user.first_name}</a>",
                 quote=True
                 # reply_to_message_id=message.message_id
             )
@@ -220,7 +221,7 @@ async def upload_to_gdrive(file_upload, message, messa_ge, g_id):
         button_markup = pyrogram.InlineKeyboardMarkup(button)
         await asyncio.sleep(EDIT_SLEEP_TIME_OUT)
         await messa_ge.reply_text(
-            f"Uploaded successfully `{os.path.basename(file_upload)}` <a href='tg://user?id={message.from_user.id}'>{message.from_user.first_name}</a>\n Size: {gjay}",
+            f"Uploaded successfully `{os.path.basename(file_upload)}` <a href='tg://user?id={update.message.from_user.id}'>{update.message.from_user.first_name}</a>\n Size: {gjay}",
             reply_markup=button_markup,
         )
         os.remove(file_upload)
@@ -289,7 +290,7 @@ async def upload_to_gdrive(file_upload, message, messa_ge, g_id):
         button_markup = pyrogram.InlineKeyboardMarkup(button)
         await asyncio.sleep(EDIT_SLEEP_TIME_OUT)
         await messa_ge.reply_text(
-            f"Uploaded successfully `{os.path.basename(file_upload)}` <a href='tg://user?id={message.from_user.id}'>{message.from_user.first_name}</a>\n Size: {gjay}",
+            f"Uploaded successfully `{os.path.basename(file_upload)}` <a href='tg://user?id={update.message.from_user.id}'>{update.message.from_user.first_name}</a>\n Size: {gjay}",
             reply_markup=button_markup,
         )
         shutil.rmtree(file_upload)
